@@ -139,14 +139,16 @@ geeglm<- function (formula, family = gaussian, data = parent.frame(),
     corstr <- CORSTRS[corstrv]
 
     call <- match.call(expand.dots = TRUE)
+
     glmcall <- call
     glmcall$id <- glmcall$jack <- glmcall$control <- glmcall$corstr <-
         glmcall$waves <- glmcall$zcor <- glmcall$std.err <-
             glmcall$scale.fix <- glmcall$scale.value <- NULL
     glmcall[[1]] <- as.name("glm")
     glmFit <- eval(glmcall, parent.frame())
-    mf <- call
-    mf[[1]] <- as.name("model.frame")
+
+
+
     
     modelmat <- model.matrix(glmFit)
     qqrr <- qr(modelmat)
@@ -154,7 +156,11 @@ geeglm<- function (formula, family = gaussian, data = parent.frame(),
         print(head(modelmat))
         stop("Model matrix is rank deficient; geeglm can not proceed\n")
     }
-    
+
+
+    mf <- call
+    mf[[1]] <- as.name("model.frame")
+
     mftmp <- mf
     mftmp$family <- mftmp$corstr <- mftmp$control <- mftmp$zcor <- mftmp$std.err <- NULL
     
@@ -211,7 +217,7 @@ geeglm<- function (formula, family = gaussian, data = parent.frame(),
                 "na.action")
     cnames <- names(call)
     cnames <- cnames[match(mnames, cnames, 0)]
-    mcall <- call[cnames]
+    mcall  <- call[cnames]
     mcall$drop.unused.levels <- TRUE
     mcall[[1]] <- as.name("model.frame")
     mcall$formula <- formula
@@ -224,17 +230,15 @@ geeglm<- function (formula, family = gaussian, data = parent.frame(),
     colnames(zsca) <- c("(Intercept)")
 
     w <- model.weights(mf)
-    if (is.null(w)) 
-        w <- rep(1, N)
+    if (is.null(w)) w <- rep(1, N)
 
     offset <- model.offset(mf)
-    if (is.null(offset)) 
-        offset <- rep(0, N)
+    if (is.null(offset)) offset <- rep(0, N)
     
     if (glmFit$family$family == "binomial") {
         if (is.matrix(yy) && ncol(yy) == 2) {
             w <- apply(yy, 1, sum)
-            yy <- yy[, 1]/w
+            yy <- yy[, 1] / w
         }
     }
 
@@ -246,6 +250,9 @@ geeglm<- function (formula, family = gaussian, data = parent.frame(),
     
     if (is.null(start)) 
         start <- glmFit$coef
+
+    ## cat("KKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKK\n")
+    ## print(id)
     
     ans <- geese.fit(xx, yy, id, offset, soffset, w, waves = waves, 
                      zsca, zcor = zcor, corp = NULL, control = control, b = start, 
@@ -288,16 +295,12 @@ geeglm<- function (formula, family = gaussian, data = parent.frame(),
     value
 }
 
-
-
-
-
-
+#' @export
 vcov.geeglm <- function(object, ...){
     out <- switch(object$std.err,
                   'jack'={object$geese$vbeta.ajs},
-                  'j1s'={object$geese$vbeta.j1s},
-                  'fij'={object$geese$vbeta.fij},
+                  'j1s' ={object$geese$vbeta.j1s},
+                  'fij' ={object$geese$vbeta.fij},
                   object$geese$vbeta
                   )
     pn <- names(coef(object))
@@ -305,25 +308,23 @@ vcov.geeglm <- function(object, ...){
     out
 }
 
-
-
-
+#' @export
 summary.geeglm <- function(object,...){
-    v1 <- summary.geese(object$geese)
+
     class(object) <- "glm"
     value <- summary.glm(object)
     class(object) <- c("geeglm","glm")
     class(value) <- "summary.geeglm"
-    toDelete <- c("deviance","aic","null.deviance","iter","df.residual","df.null",
-                  "converged","boundary")
-    idx <- match(toDelete,names(value))
+    toDelete <- c("deviance", "aic", "null.deviance", "iter", "df.residual",
+                  "df.null", "converged", "boundary")
+    idx <- match(toDelete, names(value))
     value[idx]  <- NULL
     
     covmat <- 
         switch(object$std.err,
                'jack'={object$geese$vbeta.ajs},
-               'j1s'={object$geese$vbeta.j1s},
-               'fij'={object$geese$vbeta.fij},
+               'j1s' ={object$geese$vbeta.j1s},
+               'fij' ={object$geese$vbeta.fij},
                object$geese$vbeta
                )
     value$cov.scaled   <-   value$cov.unscaled <-  covmat
@@ -336,17 +337,17 @@ summary.geeglm <- function(object,...){
     
     value$coefficients <- mean.sum
     
-    
     covmatgam <- 
         switch(object$std.err,
                'jack'={object$geese$vgamma.ajs},
-               'j1s'={object$geese$vgamma.j1s},
-               'fij'={object$geese$vgamma.fij},
+               'j1s' ={object$geese$vgamma.j1s},
+               'fij' ={object$geese$vgamma.fij},
                object$geese$vgamma
                )
+    
     scale.sum  <- data.frame(Estimate = object$geese$gamma, Std.err=sqrt(diag(covmatgam)))
-                                        #scale.sum$wald <- (scale.sum$Estimate / scale.sum$Std.err)^2
-                                        #scale.sum$p <- 1 - pchisq(scale.sum$wald, df=1)
+    ##scale.sum$wald <- (scale.sum$Estimate / scale.sum$Std.err)^2
+    ##scale.sum$p <- 1 - pchisq(scale.sum$wald, df=1)
     
     if (!is.null(object$geese$zsca.names)) rownames(scale.sum) <- object$geese$zsca.names
     value$dispersion   <-  scale.sum
@@ -354,21 +355,22 @@ summary.geeglm <- function(object,...){
     covmatalpha <- 
         switch(object$std.err,
                'jack'={object$geese$valpha.ajs},
-               'j1s'={object$geese$valpha.j1s},
-               'fij'={object$geese$valpha.fij},
+               'j1s' ={object$geese$valpha.j1s},
+               'fij' ={object$geese$valpha.fij},
                object$geese$valpha
                )
     
     corr.sum <- data.frame(Estimate = object$geese$alpha, Std.err=sqrt(diag(covmatalpha)))
-                                        #corr.sum$wald <- (corr.sum$Estimate / corr.sum$Std.err)^2
-                                        #corr.sum$p <- 1 - pchisq(corr.sum$wald, df=1)
-                                        #if (nrow(corr.sum) > 0) rownames(corr.sum) <- object$geese$zcor.names
+    ##corr.sum$wald <- (corr.sum$Estimate / corr.sum$Std.err)^2
+    ##corr.sum$p <- 1 - pchisq(corr.sum$wald, df=1)
+    ##if (nrow(corr.sum) > 0) rownames(corr.sum) <- object$geese$zcor.names
     value$corr <- corr.sum
     
-    
     value$corstr    <- object$geese$model$corstr
     value$scale.fix <- object$geese$model$scale.fix
-    value$cor.link  <-  object$geese$model$cor.link
+    value$cor.link  <- object$geese$model$cor.link
+
+    v1 <- summary.geese(object$geese)
     
     value$clusz <- v1$clusz
     value$error <- object$geese$error
@@ -379,7 +381,7 @@ summary.geeglm <- function(object,...){
 #  colnames(mean.sum) <- c("Estimate","Std.Error","ajs.SE","j1s.SE","fij.SE",
 #                          "Wald","Pr(>|z|)")
 
-
+#' @export
 print.summary.geeglm <- function (x,
          digits = max(3, getOption("digits") - 3),
          quote = FALSE, prefix = "", ...) # Thanks, Achim...
@@ -415,38 +417,46 @@ print.summary.geeglm <- function (x,
 }
 
 
+#' @export
 print.geeglm <- function (x, digits = NULL, quote = FALSE, prefix = "", ...) 
 {
-  xg <- x$geese
-  if (is.null(digits)) 
-      digits <- options()$digits
+
+    xg <- x$geese
+    if (is.null(digits))
+        digits <- options()$digits
     else options(digits = digits)
-  cat("\nCall:\n");   print(x$call)
-  cat("\nCoefficients:\n")
-  print(unclass(x$coefficients), digits = digits)
-  
-  cat("\nDegrees of Freedom:", length(x$y), "Total (i.e. Null); ", 
-      x$df.residual, "Residual\n")
-  
-  if (!xg$model$scale.fix) {
-      cat("\nScale Link:                  ", xg$model$sca.link)
-      cat("\nEstimated Scale Parameters:  ")
-      print(as.numeric(unclass(xg$gamma)), digits = digits)
-  }
-  else cat("\nScale is fixed.\n")
-  
-  cat("\nCorrelation:  Structure =",xg$model$corstr, " ")
-  if (pmatch(xg$model$corstr, "independence", 0) == 0) {
-      cat("  Link =", xg$model$cor.link, "\n")
-      cat("Estimated Correlation Parameters:\n")
-      print(unclass(xg$alpha), digits = digits)
-  }
-  cat("\nNumber of clusters:  ", length(xg$clusz), "  Maximum cluster size:", 
-      max(xg$clusz), "\n\n")
-  invisible(x)
+
+    
+    cat("\nCall:\n")
+    print(x$call)
+    cat("\nCoefficients:\n")
+    print(unclass(x$coefficients), digits = digits)
+    
+    cat("\nDegrees of Freedom:", length(x$y), "Total (i.e. Null); ", 
+        x$df.residual, "Residual\n")
+    
+    
+    
+    if (!xg$model$scale.fix) {
+        cat("\nScale Link:                  ", xg$model$sca.link)
+        cat("\nEstimated Scale Parameters:  ")
+        print(as.numeric(unclass(xg$gamma)), digits = digits)
+    }
+    else cat("\nScale is fixed.\n")
+    
+    cat("\nCorrelation:  Structure =",xg$model$corstr, " ")
+    if (pmatch(xg$model$corstr, "independence", 0) == 0) {
+        cat("  Link =", xg$model$cor.link, "\n")
+        cat("Estimated Correlation Parameters:\n")
+        print(unclass(xg$alpha), digits = digits)
+    }
+    cat("\nNumber of clusters:  ", length(xg$clusz), "  Maximum cluster size:", 
+        max(xg$clusz), "\n\n")
+    invisible(x)
 }
 
 
+#' @export
 residuals.geeglm <- function (object, type = c("pearson", "working", "response"), ...) 
 {
     type <- match.arg(type)
@@ -473,6 +483,7 @@ residuals.geeglm <- function (object, type = c("pearson", "working", "response")
     res
 }
 
+#' @export
 plot.geeglm <- function(x,...){
   xx <- fitted(x)
   rp <- residuals(x, "pearson")
